Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Poll_intf.SSourceval backend : Backend.tval create : unit -> tcreate creates a new instance of a poller.
val set : t -> Unix.file_descr -> Event.t -> unitset t fd event updates the state of the set of file descriptors monitored by the poller. Event.none can be used to delete a fd from the set of descriptors that are monitored.
wait t timeout waits for at least one event to be ready, unless the user provides timeout is reached.
val clear : t -> unitclear clears the number of i/o events that are ready to be consumed. This should be called after the user consumes all events that are available after wait.
val iter_ready : t -> f:(Unix.file_descr -> Event.t -> unit) -> unititer_ready iterates over the events that are ready after a call to wait.
val close : t -> unitclose closes the poller instance.